==> 3.2.0.tar.gz: lib/src/local_data/method_channel_ios_local_data.dart <==
// Copyright © 2022 Nevis Security AG. All rights reserved.

import 'package:flutter/services.dart';
import 'package:nevis_mobile_authentication_sdk_platform_interface/nevis_mobile_authentication_sdk_platform_interface.dart';

/// iOS side implementation of [LocalDataPlatformInterface].
class MethodChannelIosLocalData extends LocalDataPlatformInterface {
  final MethodChannel _channel;

  /// Default constructor for [MethodChannelIosLocalData].
  MethodChannelIosLocalData(this._channel);

  @override
  Future<Set<Account>> accounts(String operationId) async {
    Map<String, dynamic> message = OperationIdMessage(
      operationId: operationId,
    ).toJson();
    final response = Map<String, dynamic>.from(await _channel.invokeMethod(
      ChannelMethodNames.localData.accounts,
      message,
    ));
    final responseList = response.fromMap<List>();
    final accounts =
        (responseList.result as List).map((map) => Account.fromJson(map));
    return Set.from(accounts);
  }

  @override
  Future<Set<Authenticator>> authenticators(String operationId) async {
    Map<String, dynamic> message = OperationIdMessage(
      operationId: operationId,
    ).toJson();
    final response = Map<String, dynamic>.from(await _channel.invokeMethod(
      ChannelMethodNames.localData.authenticators,
      message,
    ));
    final responseList = response.fromMap<List>();
    final authenticators =
        (responseList.result as List).map((map) => Authenticator.fromJson(map));
    return Set.from(authenticators);
  }

  @override
  Future<void> deleteAuthenticator({
    required String operationId,
    String? username,
    required String authenticatorAaid,
  }) async {
    Map<String, dynamic> message = DeleteAuthenticatorMessage(
      operationId: operationId,
      authenticatorAaid: authenticatorAaid,
      username: username,
    ).toJson();
    await _channel.invokeMethod(
      ChannelMethodNames.localData.deleteAuthenticator,
      message,
    );
  }

  @override
  Future<DeviceInformation?> deviceInformation(String operationId) async {
    Map<String, dynamic> message = OperationIdMessage(
      operationId: operationId,
    ).toJson();
    final responseMap = await _channel.invokeMethod(
      ChannelMethodNames.localData.deviceInformation,
      message,
    );
    final response = Map<String, dynamic>.from(responseMap);
    if (response.isEmpty) {
      return null;
    }
    final responseDispatchTargetMap = response.fromMap<Map>();
    return DeviceInformation.fromJson(responseDispatchTargetMap.result);
  }
}

==> 3.4.0.tar.gz: lib/src/local_data/method_channel_ios_local_data.dart <==
// Copyright © 2022 Nevis Security AG. All rights reserved.

import 'package:flutter/services.dart';
import 'package:nevis_mobile_authentication_sdk_platform_interface/nevis_mobile_authentication_sdk_platform_interface.dart';

/// iOS side implementation of [LocalDataPlatformInterface].
class MethodChannelIosLocalData extends LocalDataPlatformInterface {
  final MethodChannel _channel;

  /// Default constructor for [MethodChannelIosLocalData].
  MethodChannelIosLocalData(this._channel);

  @override
  Future<Set<Account>> accounts(String operationId) async {
    Map<String, dynamic> message = OperationIdMessage(
      operationId: operationId,
    ).toJson();
    final response = Map<String, dynamic>.from(await _channel.invokeMethod(
      ChannelMethodNames.localData.accounts,
      message,
    ));
    final responseList = response.fromMap<List>();
    final accounts =
        (responseList.result as List).map((map) => Account.fromJson(map));
    return Set.from(accounts);
  }

  @override
  Future<Set<Authenticator>> authenticators(String operationId) async {
    Map<String, dynamic> message = OperationIdMessage(
      operationId: operationId,
    ).toJson();
    final response = Map<String, dynamic>.from(await _channel.invokeMethod(
      ChannelMethodNames.localData.authenticators,
      message,
    ));
    final responseList = response.fromMap<List>();
    final authenticators =
        (responseList.result as List).map((map) => Authenticator.fromJson(map));
    return Set.from(authenticators);
  }

  @override
  Future<DeviceInformation?> deviceInformation(String operationId) async {
    Map<String, dynamic> message = OperationIdMessage(
      operationId: operationId,
    ).toJson();
    final responseMap = await _channel.invokeMethod(
      ChannelMethodNames.localData.deviceInformation,
      message,
    );
    final response = Map<String, dynamic>.from(responseMap);
    if (response.isEmpty) {
      return null;
    }
    final responseDispatchTargetMap = response.fromMap<Map>();
    return DeviceInformation.fromJson(responseDispatchTargetMap.result);
  }

  @override
  Future<void> deleteAuthenticator({
    required String operationId,
    required String username,
    String? aaid,
  }) async {
    Map<String, dynamic> message = DeleteAuthenticatorMessage(
      operationId: operationId,
      username: username,
      aaid: aaid,
    ).toJson();
    await _channel.invokeMethod(
      ChannelMethodNames.localData.deleteAuthenticator,
      message,
    );
  }
}
